==> haskell-bzlib-0.5.1.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bzlib
version:              0.5.1.0
visibility:           public
id:                   bzlib-0.5.1.0-4u2sOiocpQUE9jH2bUpVH9
key:                  bzlib-0.5.1.0-4u2sOiocpQUE9jH2bUpVH9
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  be7e656eaa876afbf96f66d46e952a3f
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-8.10.4/site-local/bzlib-0.5.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bzlib-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/bzlib-0.5.1.0
hs-libraries:         HSbzlib-0.5.1.0-4u2sOiocpQUE9jH2bUpVH9
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bzlib-0.5.1.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bzlib
version:              0.5.1.0
visibility:           public
id:                   bzlib-0.5.1.0-AIlZwd3VoGAFhNB6wSoJQh
key:                  bzlib-0.5.1.0-AIlZwd3VoGAFhNB6wSoJQh
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  b7b3a6b3b4f141c847e380556159c53e
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-8.10.5/site-local/bzlib-0.5.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/bzlib-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/bzlib-0.5.1.0
hs-libraries:         HSbzlib-0.5.1.0-AIlZwd3VoGAFhNB6wSoJQh
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.14.2.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
